<?php die("Access Denied"); ?>#x#s:1165:"<?xml version="1.0" encoding="utf-8"?>
<extensions>
	<extension>
		<name>Advanced Module Manager</name>
		<id>advancedmodulemanager</id>
		<alias>advancedmodulemanager</alias>
		<extname>advancedmodules</extname>
		<version>9.9.0</version>
		<has_pro>1</has_pro>
		<pro>0</pro>
		<downloadurl>https://download.regularlabs.com/file.php?ext=advancedmodulemanager&amp;j=3</downloadurl>
		<downloadurl_pro></downloadurl_pro>
		<changelog><![CDATA[
<div style="font-family:monospace;font-size:1.2em;">02-Nov-2024 : v10.1.2<br> # Fixes issue with php error when using access level or usergroup conditions<br><br>18-Oct-2024 : v10.1.1<br> # Fixes issue with php error about getGroups receiving null<br><br>18-Oct-2024 : v10.1.0<br> ^ Updates translations: nl-NL, pl-PL, tr-TR<br> # Fixes issue with php error about getGroups not returning an array<br> # [PRO] Adds ability to add comments to IP lists in the conditions<br><br>26-Aug-2024 : v10.0.28<br> # Fixes issue with the Rule Type select field not working on some setups<br><br>19-Aug-2024 : v10.0.27</div><div style="text-align: right;"><i>...click for more...</i></div>
		]]></changelog>
	</extension>
</extensions>";